@@ -37,46 +37,44 @@
 ##
 #############################################################################
 
+import fnmatch
 import os
 import sys
-import fnmatch
-from .linux import prepare_standalone_package_linux
-from .macos import prepare_standalone_package_macos
 
 from ..config import config
 from ..options import OPTION
-from ..qtinfo import QtInfo
 from ..utils import copydir, copyfile, makefile
-from ..utils import regenerate_qt_resources
 from ..versions import PYSIDE, SHIBOKEN
+from .linux import prepare_standalone_package_linux
+from .macos import prepare_standalone_package_macos
 
 
-def _macos_copy_gui_executable(name, vars=None):
+def _macos_copy_gui_executable(name, _vars=None):
     """macOS helper: Copy a GUI executable from the .app folder and return the
        files"""
-    app_name = name[:1].upper() + name[1:] + '.app'
+    app_name = f"{name.capitalize()}.app"
     return copydir(f"{{install_dir}}/bin/{app_name}",
                    f"{{st_build_dir}}/{{st_package_name}}/{app_name}",
-                   filter=None, recursive=True,
-                   force=False, vars=vars)
+                   _filter=None, recursive=True,
+                   force=False, _vars=_vars)
 
 
-def _unix_copy_gui_executable(name, vars=None):
+def _unix_copy_gui_executable(name, _vars=None):
     """UNIX helper: Copy a GUI executable and return the files"""
     return copydir("{install_dir}/bin/",
                    "{st_build_dir}/{st_package_name}/",
-                   filter=[name],
-                   force=False, vars=vars)
+                   _filter=[name],
+                   force=False, _vars=_vars)
 
 
-def _copy_gui_executable(name, vars=None):
+def _copy_gui_executable(name, _vars=None):
     """Copy a GUI executable and return the files"""
-    if  sys.platform == 'darwin':
-        return _macos_copy_gui_executable(name, vars)
-    return _unix_copy_gui_executable(name, vars)
+    if sys.platform == 'darwin':
+        return _macos_copy_gui_executable(name, _vars)
+    return _unix_copy_gui_executable(name, _vars)
 
 
-def prepare_packages_posix(self, vars):
+def prepare_packages_posix(self, _vars):
     executables = []
     libexec_executables = []
 
@@ -87,16 +85,16 @@ def prepare_packages_posix(self, vars):
     copydir(
         "{site_packages_dir}/{st_package_name}",
         "{st_build_dir}/{st_package_name}",
-        vars=vars)
+        _vars=_vars)
 
-    generated_config = self.get_built_pyside_config(vars)
+    generated_config = self.get_built_pyside_config(_vars)
 
     def adjusted_lib_name(name, version):
         postfix = ''
         if sys.platform.startswith('linux'):
-            postfix = '.so.' + version
+            postfix = f".so.{version}"
         elif sys.platform == 'darwin':
-            postfix = '.' + version + '.dylib'
+            postfix = f".{version}.dylib"
         return name + postfix
 
     if config.is_internal_shiboken_module_build():
@@ -105,125 +103,130 @@ def prepare_packages_posix(self, vars):
         copydir(
             f"{{build_dir}}/{SHIBOKEN}/doc/html",
             f"{{st_build_dir}}/{{st_package_name}}/docs/{SHIBOKEN}",
-            force=False, vars=vars)
+            force=False, _vars=_vars)
 
         # <install>/lib/lib* -> {st_package_name}/
         copydir(
             "{install_dir}/lib/",
             "{st_build_dir}/{st_package_name}",
-            filter=[
+            _filter=[
                 adjusted_lib_name("libshiboken*",
                                   generated_config['shiboken_library_soversion']),
             ],
-            recursive=False, vars=vars, force_copy_symlinks=True)
+            recursive=False, _vars=_vars, force_copy_symlinks=True)
 
     if config.is_internal_shiboken_generator_build():
         # <install>/bin/* -> {st_package_name}/
         executables.extend(copydir(
             "{install_dir}/bin/",
             "{st_build_dir}/{st_package_name}",
-            filter=[SHIBOKEN],
-            recursive=False, vars=vars))
+            _filter=[SHIBOKEN],
+            recursive=False, _vars=_vars))
 
         # Used to create scripts directory.
         makefile(
             "{st_build_dir}/{st_package_name}/scripts/shiboken_tool.py",
-            vars=vars)
+            _vars=_vars)
 
         # For setting up setuptools entry points.
         copyfile(
             "{install_dir}/bin/shiboken_tool.py",
             "{st_build_dir}/{st_package_name}/scripts/shiboken_tool.py",
-            force=False, vars=vars)
+            force=False, _vars=_vars)
 
     if config.is_internal_shiboken_generator_build() or config.is_internal_pyside_build():
         # <install>/include/* -> <setup>/{st_package_name}/include
         copydir(
             "{install_dir}/include/{cmake_package_name}",
             "{st_build_dir}/{st_package_name}/include",
-            vars=vars)
+            _vars=_vars)
 
     if config.is_internal_pyside_build():
         makefile(
             "{st_build_dir}/{st_package_name}/scripts/__init__.py",
-            vars=vars)
+            _vars=_vars)
 
         # For setting up setuptools entry points
-        copyfile(
-            "{install_dir}/bin/pyside_tool.py",
-            "{st_build_dir}/{st_package_name}/scripts/pyside_tool.py",
-            force=False, vars=vars)
+        for script in ("pyside_tool.py", "metaobjectdump.py", "project.py"):
+            src = f"{{install_dir}}/bin/{script}"
+            target = f"{{st_build_dir}}/{{st_package_name}}/scripts/{script}"
+            copyfile(src, target, force=False, _vars=_vars)
 
         # <install>/bin/* -> {st_package_name}/
         executables.extend(copydir(
             "{install_dir}/bin/",
             "{st_build_dir}/{st_package_name}",
-            filter=[f"{PYSIDE}-lupdate"],
-            recursive=False, vars=vars))
-
+            _filter=[f"{PYSIDE}-lupdate"],
+            recursive=False, _vars=_vars))
 
         lib_exec_filters = []
         if not OPTION['NO_QT_TOOLS']:
-            lib_exec_filters.extend(['uic', 'rcc'])
+            lib_exec_filters.extend(['uic', 'rcc', 'qmltyperegistrar'])
             executables.extend(copydir(
                 "{install_dir}/bin/",
                 "{st_build_dir}/{st_package_name}",
-                filter=["lrelease", "lupdate"],
-                recursive=False, vars=vars))
+                _filter=["lrelease", "lupdate", "qmllint"],
+                recursive=False, _vars=_vars))
             # Copying assistant/designer
-            executables.extend(_copy_gui_executable('assistant', vars=vars))
-            executables.extend(_copy_gui_executable('designer', vars=vars))
-            executables.extend(_copy_gui_executable('linguist', vars=vars))
+            executables.extend(_copy_gui_executable('assistant', _vars=_vars))
+            executables.extend(_copy_gui_executable('designer', _vars=_vars))
+            executables.extend(_copy_gui_executable('linguist', _vars=_vars))
+
+        # <qt>/lib/metatypes/* -> <setup>/{st_package_name}/Qt/lib/metatypes
+        destination_lib_dir = "{st_build_dir}/{st_package_name}/Qt/lib"
+        copydir("{qt_lib_dir}/metatypes", f"{destination_lib_dir}/metatypes",
+                _filter=["*.json"],
+                recursive=False, _vars=_vars, force_copy_symlinks=True)
 
         # Copy libexec
-        built_modules = self.get_built_pyside_config(vars)['built_modules']
+        built_modules = self.get_built_pyside_config(_vars)['built_modules']
         if self.is_webengine_built(built_modules):
             lib_exec_filters.append('QtWebEngineProcess')
         if lib_exec_filters:
             libexec_executables.extend(copydir("{qt_lib_execs_dir}",
                                                "{st_build_dir}/{st_package_name}/Qt/libexec",
-                                               filter=lib_exec_filters,
+                                               _filter=lib_exec_filters,
                                                recursive=False,
-                                               vars=vars))
+                                               _vars=_vars))
 
         # <install>/lib/lib* -> {st_package_name}/
         copydir(
             "{install_dir}/lib/",
             "{st_build_dir}/{st_package_name}",
-            filter=[
+            _filter=[
                 adjusted_lib_name("libpyside*",
                                   generated_config['pyside_library_soversion']),
             ],
-            recursive=False, vars=vars, force_copy_symlinks=True)
+            recursive=False, _vars=_vars, force_copy_symlinks=True)
 
         # <install>/share/{st_package_name}/typesystems/* ->
         #   <setup>/{st_package_name}/typesystems
         copydir(
             "{install_dir}/share/{st_package_name}/typesystems",
             "{st_build_dir}/{st_package_name}/typesystems",
-            vars=vars)
+            _vars=_vars)
 
         # <install>/share/{st_package_name}/glue/* ->
         #   <setup>/{st_package_name}/glue
         copydir(
             "{install_dir}/share/{st_package_name}/glue",
             "{st_build_dir}/{st_package_name}/glue",
-            vars=vars)
+            _vars=_vars)
 
         # <source>/pyside6/{st_package_name}/support/* ->
         #   <setup>/{st_package_name}/support/*
         copydir(
             f"{{build_dir}}/{PYSIDE}/{{st_package_name}}/support",
             "{st_build_dir}/{st_package_name}/support",
-            vars=vars)
+            _vars=_vars)
 
         # <source>/pyside6/{st_package_name}/*.pyi ->
         #   <setup>/{st_package_name}/*.pyi
         copydir(
             f"{{build_dir}}/{PYSIDE}/{{st_package_name}}",
             "{st_build_dir}/{st_package_name}",
-            filter=["*.pyi", "py.typed"],
-            vars=vars)
+            _filter=["*.pyi", "py.typed"],
+            _vars=_vars)
 
         if not OPTION["NOEXAMPLES"]:
             def pycache_dir_filter(dir_name, parent_full_path, dir_full_path):
@@ -233,23 +236,16 @@ def prepare_packages_posix(self, vars):
             # examples/* -> <setup>/{st_package_name}/examples
             copydir(os.path.join(self.script_dir, "examples"),
                     "{st_build_dir}/{st_package_name}/examples",
-                    force=False, vars=vars, dir_filter_function=pycache_dir_filter)
-            # Re-generate examples Qt resource files for Python 3
-            # compatibility
-            examples_path = "{st_build_dir}/{st_package_name}/examples".format(**vars)
-            lib_execs_dir = QtInfo().lib_execs_dir
-            pyside_rcc_path = f"{lib_execs_dir}/rcc"
-            pyside_rcc_options = ['-g', 'python']
-            regenerate_qt_resources(examples_path, pyside_rcc_path, pyside_rcc_options)
+                    force=False, _vars=_vars, dir_filter_function=pycache_dir_filter)
 
     # Copy Qt libs to package
     if OPTION["STANDALONE"]:
         if config.is_internal_pyside_build() or config.is_internal_shiboken_generator_build():
-            vars['built_modules'] = generated_config['built_modules']
+            _vars['built_modules'] = generated_config['built_modules']
             if sys.platform == 'darwin':
-                prepare_standalone_package_macos(self, vars)
+                prepare_standalone_package_macos(self, _vars)
             else:
-                prepare_standalone_package_linux(self, vars)
+                prepare_standalone_package_linux(self, _vars)
 
         if config.is_internal_shiboken_generator_build():
             # Copy over clang before rpath patching.
@@ -257,7 +253,7 @@ def prepare_packages_posix(self, vars):
 
     # Update rpath to $ORIGIN
     if sys.platform.startswith('linux') or sys.platform.startswith('darwin'):
-        rpath_path = "{st_build_dir}/{st_package_name}".format(**vars)
+        rpath_path = "{st_build_dir}/{st_package_name}".format(**_vars)
         self.update_rpath(rpath_path, executables)
         self.update_rpath(rpath_path, self.package_libraries(rpath_path))
         if libexec_executables:
